<?php

/**
 * Returns HTML for a fieldset form element and its children.
 *
 * @param $variables
 *   An associative array containing:
 *   - element: An associative array containing the properties of the element.
 *     Properties used: #attributes, #children, #collapsed, #collapsible,
 *     #description, #id, #title, #value.
 *
 * @ingroup themeable
 */
function twbs_fieldset($variables) {
  $element = $variables['element'];
  element_set_attributes($element, array('id'));

  $output = '';

  // Normal fieldset without virtual tab grouping.
  if (!isset($element['#group'])) {
    _form_set_class($element, array('form-wrapper'));

    $output .= '<fieldset' . drupal_attributes($element['#attributes']) . '>';
    if (!empty($element['#title'])) {
      // Always wrap fieldset legends in a SPAN for CSS positioning.
      $output .= '<legend><span class="fieldset-legend">' . $element['#title'] . '</span></legend>';
    }
    $output .= '<div class="fieldset-wrapper">';
    if (!empty($element['#description'])) {
      $output .= '<div class="fieldset-description">' . $element['#description'] . '</div>';
    }
    $output .= $element['#children'];
    if (isset($element['#value'])) {
      $output .= $element['#value'];
    }
    $output .= '</div>';
    $output .= "</fieldset>\n";
  }
  // Virtual tab under TWBS convert as collapse.
  else {
    $output .= '<div class="panel panel-default">';

    if (!empty($element['#title'])) {
      $output .= '<div class="panel-heading"><h4 class="panel-title">';
      $output .= '<a data-toggle="collapse" data-parent="#' . $element['#group'] . '" href="#' . $element['#id'] . '">';
      $output .= $element['#title'];
      $output .= '</a>';
      $output .= '</h4></div>';
    }

    $output .= '<div id="' . $element['#id'] . '" class="panel-collapse collapse"><div class="panel-body">';
    if (!empty($element['#description'])) {
      $output .= '<p>' . $element['#description'] . '</p>';
    }
    $output .= $element['#children'];
    if (isset($element['#value'])) {
      $output .= $element['#value'];
    }
    $output .= '</div></div>';

    $output .= '</div>';
  }

  return $output;
}
