<?php

/**
 * @file
 * Default theme implementation to display a single Drupal page while offline.
 *
 * All the available variables are mirrored in html.tpl.php and page.tpl.php.
 * Some may be blank but they are provided for consistency.
 *
 * @see template_preprocess()
 * @see twbs_preprocess_maintenance_page()
 *
 * @ingroup themeable
 */
?>
<!DOCTYPE html>
<html lang="<?php print $language->language; ?>" dir="<?php print $language->dir; ?>">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <?php print $head; ?>
        <title><?php print $head_title; ?></title>
        <?php print $styles; ?>
        <?php print $scripts; ?>
    </head>
    <body class="<?php print $classes; ?>" <?php print $attributes;?>>
        <div id="skip-link">
            <a href="#main-content" class="sr-only"><?php print t('Skip to main content'); ?></a>
        </div>

        <div id="navigation" class="navbar navbar-default navbar-static-top" role="navigation">
            <div class="container">
                <div class="navbar-header">
                    <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navigation .navbar-collapse">
                        <span class="sr-only">Toggle navigation</span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                    </button>
                    <?php if ($logo): ?>
                    <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" class="navbar-text" id="logo">
                        <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
                    </a>
                    <?php endif; ?>
                    <?php if ($site_name): ?>
                    <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" class="navbar-brand" id="site-name">
                        <?php print $site_name; ?>
                    </a>
                    <?php endif; ?>
                    <?php if ($site_slogan): ?>
                    <div class="navbar-text" id="site-slogan">
                        <?php print $site_slogan; ?>
                    </div>
                    <?php endif; ?>
                </div> <!-- /.navbar-header -->
                <div class="navbar-collapse collapse">
                    <?php print theme('links__system_main_menu', array(
                        'links' => $main_menu,
                        'attributes' => array(
                            'id' => 'main-menu',
                            'class' => array('nav', 'navbar-nav'),
                        ),
                    )); ?>
                    <?php print theme('links__system_secondary_menu', array(
                        'links' => $secondary_menu,
                        'attributes' => array(
                            'id' => 'secondary-menu',
                            'class' => array('nav', 'navbar-nav', 'navbar-right'),
                        ),
                    )); ?>
                </div> <!-- /.nav-collapse -->
            </div>
        </div> <!-- /#navigation -->

        <div id="page" class="container">

            <?php print render($page['header']); ?>

            <div id="main" class="row">

                <?php if ($breadcrumb): ?>
                <div id="breadcrumb" class="col-lg-12">
                    <?php print $breadcrumb; ?>
                </div>
                <?php endif; ?>

                <?php if ($messages): ?>
                <div id="messages" class="col-lg-12">
                    <?php print $messages; ?>
                </div>
                <?php endif; ?>

                <?php if ($page['sidebar_first']): ?>
                <div class="sidebar col-lg-3">
                    <?php print render($page['sidebar_first']); ?>
                </div>
                <?php endif; ?>

                <div id="content" class="<?php print $layout; ?>">

                    <?php print render($page['highlighted']); ?>

                    <a id="main-content"></a>

                    <?php print render($title_prefix); ?>
                    <?php if ($title): ?>
                    <div class="page-header">
                        <h1><?php print $title; ?></h1>
                    </div>
                    <?php endif; ?>
                    <?php print render($title_suffix); ?>

                    <?php print render($tabs); ?>
                    <?php print render($page['help']); ?>

                    <?php if ($action_links): ?>
                    <ul class="action-links"><?php print render($action_links); ?></ul>
                    <?php endif; ?>

                    <?php print render($page['content']); ?>

                    <?php print $feed_icons; ?>

                </div> <!-- /#content -->

                <?php if ($page['sidebar_second']): ?>
                <div class="sidebar col-lg-3">
                    <?php print render($page['sidebar_second']); ?>
                </div>
                <?php endif; ?>

            </div> <!-- /#main -->

            <?php print render($page['footer']); ?>

        </div> <!-- /#page -->

    </body>
</html>
